@@ -5,7 +5,7 @@ use unicode_width::UnicodeWidthStr;
 use crate::cell::{Cell, Cells};
 
 /// Each row contains [Cells](crate::Cell) and can be added to a [Table](crate::Table).
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 pub struct Row {
     /// Index of the row.
     /// This will be set as soon as the row is added to the table.
@@ -14,19 +14,9 @@ pub struct Row {
     pub(crate) max_height: Option<usize>,
 }
 
-impl Default for Row {
-    fn default() -> Self {
-        Self::new()
-    }
-}
-
 impl Row {
-    pub fn new() -> Row {
-        Row {
-            index: None,
-            cells: Vec::new(),
-            max_height: None,
-        }
+    pub fn new() -> Self {
+        Self::default()
     }
 
     /// Add a cell to the row.
@@ -102,8 +92,8 @@ impl Row {
 /// let row = Row::from(vec![1, 2, 3, 4]);
 /// ```
 impl<T: Into<Cells>> From<T> for Row {
-    fn from(cells: T) -> Row {
-        Row {
+    fn from(cells: T) -> Self {
+        Self {
             index: None,
             cells: cells.into().0,
             max_height: None,
