@@ -1,11 +1,10 @@
 use std::collections::HashMap;
-use std::convert::TryInto;
 use std::fmt;
 use std::iter::IntoIterator;
 use std::slice::{Iter, IterMut};
 
 #[cfg(feature = "tty")]
-use crossterm::terminal::size;
+use crossterm::terminal;
 #[cfg(feature = "tty")]
 use crossterm::tty::IsTty;
 use strum::IntoEnumIterator;
@@ -31,6 +30,8 @@ pub struct Table {
     pub(crate) arrangement: ContentArrangement,
     pub(crate) delimiter: Option<char>,
     no_tty: bool,
+    #[cfg(feature = "tty")]
+    use_stderr: bool,
     table_width: Option<u16>,
     enforce_styling: bool,
 }
@@ -50,13 +51,15 @@ impl Default for Table {
 impl Table {
     /// Create a new table with default ASCII styling.
     pub fn new() -> Self {
-        let mut table = Table {
+        let mut table = Self {
             columns: Vec::new(),
             header: None,
             rows: Vec::new(),
             arrangement: ContentArrangement::Disabled,
             delimiter: None,
             no_tty: false,
+            #[cfg(feature = "tty")]
+            use_stderr: false,
             table_width: None,
             style: HashMap::new(),
             enforce_styling: false,
@@ -138,13 +141,13 @@ impl Table {
     /// This will be `Some(width)`, if the terminal width can be detected or if the table width is set via [set_table_width](Table::set_table_width).
     ///
     /// If neither is not possible, `None` will be returned.\
-    /// This implies that both the [Dynamic](ContentArrangement::Dynamic) mode and the [Percentage](crate::style::ColumnConstraint::Percentage) constraint won't work.
+    /// This implies that both the [Dynamic](ContentArrangement::Dynamic) mode and the [Percentage](crate::style::Width::Percentage) constraint won't work.
     #[cfg(feature = "tty")]
     pub fn get_table_width(&self) -> Option<u16> {
         if let Some(width) = self.table_width {
             Some(width)
         } else if self.is_tty() {
-            if let Ok((table_width, _)) = size() {
+            if let Ok((table_width, _)) = terminal::size() {
                 Some(table_width)
             } else {
                 None
@@ -156,11 +159,7 @@ impl Table {
 
     #[cfg(not(feature = "tty"))]
     pub fn get_table_width(&self) -> Option<u16> {
-        if let Some(width) = self.table_width {
-            Some(width)
-        } else {
-            None
-        }
+        self.table_width
     }
 
     /// Specify how Comfy Table should arrange the content in your table.
@@ -204,17 +203,31 @@ impl Table {
         self
     }
 
+    /// Use this function to check whether `stderr` is a tty.
+    ///
+    /// The default is `stdout`.
+    #[cfg(feature = "tty")]
+    pub fn use_stderr(&mut self) -> &mut Self {
+        self.use_stderr = true;
+
+        self
+    }
+
     /// Returns whether the table will be handled as if it's printed to a tty.
     ///
-    /// This function respects the [Table::force_no_tty] function.\
-    /// Otherwise we try to determine, if we are on a tty.
+    /// By default, comfy-table looks at `stdout` and checks whether it's a tty.
+    /// This behavior can be changed via [Table::force_no_tty] and [Table::use_stderr].
     #[cfg(feature = "tty")]
     pub fn is_tty(&self) -> bool {
         if self.no_tty {
             return false;
         }
 
-        ::std::io::stdout().is_tty()
+        if self.use_stderr {
+            ::std::io::stderr().is_tty()
+        } else {
+            ::std::io::stdout().is_tty()
+        }
     }
 
     #[cfg(not(feature = "tty"))]
@@ -358,7 +371,6 @@ impl Table {
     /// table.load_preset(UTF8_FULL);
     /// table.apply_modifier(UTF8_ROUND_CORNERS);
     /// ```
-
     pub fn apply_modifier(&mut self, modifier: &str) -> &mut Self {
         let mut components = TableComponent::iter();
 
@@ -633,6 +645,6 @@ mod tests {
         table.add_row(&vec!["", "", "shorter"]);
         assert_eq!(table.column_max_content_widths(), vec![4, 5, 22]);
 
-        println!("{}", table);
+        println!("{table}");
     }
 }
